# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "account_enabled": "accountEnabled",
    "app_role_assignment_required": "appRoleAssignmentRequired",
    "app_roles": "appRoles",
    "application_id": "applicationId",
    "application_object_id": "applicationObjectId",
    "available_to_other_tenants": "availableToOtherTenants",
    "client_certificate_password": "clientCertificatePassword",
    "client_certificate_path": "clientCertificatePath",
    "client_id": "clientId",
    "client_secret": "clientSecret",
    "display_name": "displayName",
    "end_date": "endDate",
    "end_date_relative": "endDateRelative",
    "force_password_change": "forcePasswordChange",
    "group_membership_claims": "groupMembershipClaims",
    "group_object_id": "groupObjectId",
    "identifier_uris": "identifierUris",
    "immutable_id": "immutableId",
    "key_id": "keyId",
    "logout_url": "logoutUrl",
    "mail_nickname": "mailNickname",
    "member_object_id": "memberObjectId",
    "msi_endpoint": "msiEndpoint",
    "oauth2_allow_implicit_flow": "oauth2AllowImplicitFlow",
    "oauth2_permissions": "oauth2Permissions",
    "object_id": "objectId",
    "onpremises_sam_account_name": "onpremisesSamAccountName",
    "onpremises_user_principal_name": "onpremisesUserPrincipalName",
    "optional_claims": "optionalClaims",
    "prevent_duplicate_names": "preventDuplicateNames",
    "public_client": "publicClient",
    "reply_urls": "replyUrls",
    "required_resource_accesses": "requiredResourceAccesses",
    "service_principal_id": "servicePrincipalId",
    "start_date": "startDate",
    "subscription_id": "subscriptionId",
    "tenant_id": "tenantId",
    "usage_location": "usageLocation",
    "use_msi": "useMsi",
    "user_principal_name": "userPrincipalName",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "accountEnabled": "account_enabled",
    "appRoleAssignmentRequired": "app_role_assignment_required",
    "appRoles": "app_roles",
    "applicationId": "application_id",
    "applicationObjectId": "application_object_id",
    "availableToOtherTenants": "available_to_other_tenants",
    "clientCertificatePassword": "client_certificate_password",
    "clientCertificatePath": "client_certificate_path",
    "clientId": "client_id",
    "clientSecret": "client_secret",
    "displayName": "display_name",
    "endDate": "end_date",
    "endDateRelative": "end_date_relative",
    "forcePasswordChange": "force_password_change",
    "groupMembershipClaims": "group_membership_claims",
    "groupObjectId": "group_object_id",
    "identifierUris": "identifier_uris",
    "immutableId": "immutable_id",
    "keyId": "key_id",
    "logoutUrl": "logout_url",
    "mailNickname": "mail_nickname",
    "memberObjectId": "member_object_id",
    "msiEndpoint": "msi_endpoint",
    "oauth2AllowImplicitFlow": "oauth2_allow_implicit_flow",
    "oauth2Permissions": "oauth2_permissions",
    "objectId": "object_id",
    "onpremisesSamAccountName": "onpremises_sam_account_name",
    "onpremisesUserPrincipalName": "onpremises_user_principal_name",
    "optionalClaims": "optional_claims",
    "preventDuplicateNames": "prevent_duplicate_names",
    "publicClient": "public_client",
    "replyUrls": "reply_urls",
    "requiredResourceAccesses": "required_resource_accesses",
    "servicePrincipalId": "service_principal_id",
    "startDate": "start_date",
    "subscriptionId": "subscription_id",
    "tenantId": "tenant_id",
    "usageLocation": "usage_location",
    "useMsi": "use_msi",
    "userPrincipalName": "user_principal_name",
}
